#!/bin/bash

LOG="sample04.log"
cp -rp ~/login.cl .

#初期値の代入
lsigma=3.0
usigma=3.0
lower="INDEF"
upper="INDEF"
filename="abc.fits"
format="yes"
nclip=0


help(){
    printf "Example: ./sample04.sh -f ./image.fits -a 2 -b 2 -l -999999 -u 999999\n" 1>&2
    printf "Options: -h : show this help\n" 1>&2
    printf "Options: -a [lsigma] : default ${lsigma}\n" 1>&2
    printf "Options: -b [usigma] : default ${usigma}\n" 1>&2
    printf "Options: -l [lower] : default ${lower}\n" 1>&2
    printf "Options: -u [upper] : default ${upper}\n" 1>&2
    printf "Options: -f : [filename]\n" 1>&2
    printf "Options: -n [nclip] : default ${nclip}\n" 1>&2
    printf "Options: -t : format no : default yes\n" 1>&2
}

while getopts "ha:b:l:u:f:n:t" opt
do
    case $opt in
        h)help;
            exit 0;;
        a)lsigma=$OPTARG;;
        b)usigma=${OPTARG};;
        l)lower=${OPTARG};;
        u)upper=${OPTARG};;
        f)filename=${OPTARG};;
        n)nclip=${OPTARG};;
        t)format="no";;
    esac
done

# エラー処理
# filenameが明示されてない時、エラーメッセージを出して終了。
if [ ${filename} = "abc.fits" ]
then
    echo "You must input a filename with the -f option"
    exit 1
fi
# lower >= upperな状況の時は、エラーメッセージを出して終了。
if [ ${lower} != "INDEF" -a ${upper} != "INDEF" ]
then
    bool=`echo "${upper} - ${lower} > 0" | bc -l`
    if [ ${bool} -ne 1 ]
    then
	echo "[upper] must be larger than [lower]"
	exit 2
    fi
fi

echo "\n\n imstat ${filename} with : nclip=${nclip}, lower=${lower}, upper=${upper}, lsigma=${lsigma}, usigma=${usigma} \n\n" | tee -a ${LOG} 2>&1 

( (cl -old | tee -a ${LOG}) 2>&1 ) <<EOF
images
imutil
imstat (images="${filename}", fields="image,npix,mean,stddev,min,max", lower=${lower}, upper=${upper}, nclip=${nclip}, lsigma=${lsigma}, usigma=${usigma}, binwidth=0.1, format=${format}, cache=no)
logout
EOF
